"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createCosmosConfig = createCosmosConfig;

var _path = _interopRequireDefault(require("path"));

var _shared = require("./shared");

var _cosmosConfigPath = require("./cosmosConfigPath");

var _resolve = require("./resolve");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function createCosmosConfig(cosmosConfigInput = {}) {
  const cosmosConfigPath = (0, _cosmosConfigPath.getCosmosConfigPath)();
  const rootDir = getRootDir(cosmosConfigInput, cosmosConfigPath);
  return _objectSpread({}, cosmosConfigInput, {
    rootDir,
    exportPath: getExportPath(cosmosConfigInput, rootDir),
    staticPath: getStaticPath(cosmosConfigInput, rootDir),
    publicUrl: getPublicUrl(cosmosConfigInput),
    fixturesDir: getFixturesDir(cosmosConfigInput),
    fixtureFileSuffix: getFixtureFileSuffix(cosmosConfigInput),
    watchDirs: getWatchDirs(cosmosConfigInput, rootDir),
    userDepsFilePath: getUserDepsFilePath(cosmosConfigInput, rootDir),
    hostname: getHostname(cosmosConfigInput),
    port: getPort(cosmosConfigInput),
    globalImports: getGlobalImports(cosmosConfigInput, rootDir),
    ui: cosmosConfigInput.ui || {}
  });
}

function getRootDir({
  rootDir
}, cosmosConfigPath) {
  const cliArgs = (0, _shared.getCliArgs)();

  if (typeof cliArgs.rootDir === 'string') {
    return (0, _shared.getRootDirAtPath)(cliArgs.rootDir);
  }

  const configDir = _path.default.dirname(cosmosConfigPath);

  return rootDir ? _path.default.resolve(configDir, rootDir) : configDir;
}

function getExportPath(cosmosConfigInput, rootDir) {
  const {
    exportPath = 'cosmos-export'
  } = cosmosConfigInput;
  return (0, _resolve.resolvePath)(rootDir, exportPath);
}

function getStaticPath(cosmosConfigInput, rootDir) {
  const {
    staticPath = null
  } = cosmosConfigInput;
  return staticPath && (0, _resolve.resolvePath)(rootDir, staticPath);
}

function getPublicUrl({
  publicUrl = '/'
}) {
  return publicUrl;
}

function getFixturesDir({
  fixturesDir = '__fixtures__'
}) {
  return fixturesDir;
}

function getFixtureFileSuffix({
  fixtureFileSuffix = 'fixture'
}) {
  return fixtureFileSuffix;
}

function getWatchDirs(cosmosConfigInput, rootDir) {
  const {
    watchDirs = ['.']
  } = cosmosConfigInput;
  return watchDirs.map(watchDir => (0, _resolve.resolvePath)(rootDir, watchDir));
}

function getUserDepsFilePath(cosmosConfigInput, rootDir) {
  const {
    userDepsFilePath = 'cosmos.userdeps.js'
  } = cosmosConfigInput;
  return (0, _resolve.resolvePath)(rootDir, userDepsFilePath);
}

function getHostname({
  hostname = null
}) {
  return hostname;
}

function getPort(cosmosConfigInput) {
  const cliArgs = (0, _shared.getCliArgs)();

  if (typeof cliArgs.port === 'number') {
    return cliArgs.port;
  }

  const {
    port = 5000
  } = cosmosConfigInput;
  return port;
}

function getGlobalImports(cosmosConfigInput, rootDir) {
  const {
    globalImports = []
  } = cosmosConfigInput;
  return globalImports.map(globalImport => (0, _resolve.resolveModule)(rootDir, globalImport));
}