"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.openFile = openFile;

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

var _open = _interopRequireDefault(require("open"));

var _launchEditor = _interopRequireDefault(require("@skidding/launch-editor"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function openFile({
  cosmosConfig,
  expressApp
}) {
  expressApp.get('/_open', (req, res) => {
    const {
      filePath,
      line,
      column
    } = getReqQuery(req);

    if (!filePath) {
      res.status(400).send(`File path missing`);
      return;
    }

    const absFilePath = resolveFilePath(cosmosConfig, filePath);

    if (!_fs.default.existsSync(absFilePath)) {
      res.status(404).send(`File not found at path: ${absFilePath}`);
      return;
    }

    new Promise((resolve, reject) => {
      const file = `${absFilePath}:${line}:${column}`;
      (0, _launchEditor.default)(file, (fileName, errorMsg) => reject(errorMsg)); // If launchEditor doesn't report error within 500ms we assume it worked

      setTimeout(resolve, 500);
    }) // Fall back to open in case launchEditor fails. launchEditor only works
    // when the editor app is already open, but is favorable because it can
    // open a code file on a specific line & column.
    .catch(err => (0, _open.default)(absFilePath)).catch(err => res.status(500).send('Failed to open file')).then(() => res.send());
  });
}

function getReqQuery(req) {
  const filePath = req.query.filePath;
  const line = req.query.line ? parseInt(req.query.line, 10) : 1;
  const column = req.query.column ? parseInt(req.query.column, 10) : 1;
  return {
    filePath,
    line,
    column
  };
}

function resolveFilePath(cosmosConfig, filePath) {
  // This heuristic is needed because the open file endpoint is used for
  // multiple applications, which provide different file path types:
  // 1. Edit fixture button: Sends path relative to Cosmos rootDir
  // 2. react-error-overlay runtime error: Sends absolute path
  // 3. react-error-overlay compile error: Sends path relative to CWD
  if (_path.default.isAbsolute(filePath)) {
    return filePath;
  }

  const cosmosRelPath = _path.default.join(cosmosConfig.rootDir, filePath);

  const cwdRelPath = _path.default.join(process.cwd(), filePath);

  return _fs.default.existsSync(cosmosRelPath) ? cosmosRelPath : cwdRelPath;
}