"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.userDepsFile = userDepsFile;

var _path = _interopRequireDefault(require("path"));

var _fs = require("fs");

var _util = _interopRequireDefault(require("util.promisify"));

var _chokidar = require("chokidar");

var _lodash = require("lodash");

var _userDeps = require("../shared/userDeps");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const writeFileAsync = (0, _util.default)(_fs.writeFile);

async function userDepsFile({
  cosmosConfig
}) {
  await generateUserDepsFile(cosmosConfig);
  const watcher = await startFixtureFileWatcher(cosmosConfig);
  return () => {
    watcher.close();
  };
}

const DEBOUNCE_INTERVAL = 50;

async function startFixtureFileWatcher(cosmosConfig) {
  const {
    fixturesDir,
    fixtureFileSuffix
  } = cosmosConfig;
  const FILE_PATTERNS = [...(0, _userDeps.getFixturePatterns)(fixturesDir, fixtureFileSuffix), ...(0, _userDeps.getDecoratorPatterns)()];
  return new Promise(resolve => {
    const watcher = (0, _chokidar.watch)(FILE_PATTERNS, {
      ignored: (0, _userDeps.getIgnorePatterns)(),
      ignoreInitial: true,
      cwd: cosmosConfig.rootDir
    }).on('ready', () => resolve(watcher)).on('all', (0, _lodash.debounce)(() => generateUserDepsFile(cosmosConfig), DEBOUNCE_INTERVAL));
  });
}

async function generateUserDepsFile(cosmosConfig) {
  const {
    userDepsFilePath,
    port
  } = cosmosConfig;
  const rendererConfig = {
    port
  };
  const userDepsModule = await (0, _userDeps.generateUserDepsModule)(cosmosConfig, rendererConfig);
  await writeFileAsync(userDepsFilePath, userDepsModule, 'utf8');

  const relUserDepsFilePath = _path.default.relative(process.cwd(), userDepsFilePath);

  console.log(`[Cosmos] Generated ${relUserDepsFilePath}`);
}