"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createWebpackCosmosConfig = createWebpackCosmosConfig;

var _path = _interopRequireDefault(require("path"));

var _config = require("../../../config");

var _fs = require("../../../shared/fs");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function createWebpackCosmosConfig(cosmosConfig) {
  const {
    rootDir
  } = cosmosConfig;
  const configInput = cosmosConfig.webpack || {};
  return {
    configPath: getWebpackConfigPath(configInput, rootDir),
    overridePath: getWebpackOverridePath(configInput, rootDir),
    hotReload: getHotReload(configInput)
  };
}

function getWebpackConfigPath({
  configPath
}, rootDir) {
  if (typeof configPath === 'undefined') {
    return (0, _config.resolveModule)(rootDir, 'webpack.config.js');
  } // User can choose to prevent automatical use of an existing webpack.config.js
  // file (relative to the root dir) by setting configPath to null


  if (!configPath) {
    return null;
  }

  const absPath = (0, _config.resolveModule)(rootDir, configPath);

  if (!(0, _fs.fileExists)(absPath)) {
    const relPath = _path.default.relative(process.cwd(), absPath);

    throw new Error(`webpack config not found at path: ${relPath}`);
  }

  return absPath;
}

function getWebpackOverridePath({
  overridePath
}, rootDir) {
  if (typeof overridePath === 'undefined') {
    return (0, _config.resolveModule)(rootDir, 'webpack.override.js');
  } // User can choose to prevent automatical use of an existing webpack.override.js
  // file (relative to the root dir) by setting overridePath to null


  if (!overridePath) {
    return null;
  }

  const absPath = (0, _config.resolveModule)(rootDir, overridePath);

  if (!(0, _fs.fileExists)(absPath)) {
    const relPath = _path.default.relative(process.cwd(), absPath);

    throw new Error(`webpack override module not found at path: ${relPath}`);
  }

  return absPath;
}

function getHotReload({
  hotReload = true
}) {
  return hotReload;
}