"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.webpackDevServer = webpackDevServer;

var _path = _interopRequireDefault(require("path"));

var _webpackHotMiddleware = _interopRequireDefault(require("@skidding/webpack-hot-middleware"));

var _config = require("../../config");

var _static = require("../../shared/static");

var _shared = require("./shared");

var _webpack = require("./cosmosConfig/webpack");

var _webpackConfig = require("./webpackConfig");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

async function webpackDevServer({
  cosmosConfig,
  expressApp,
  sendMessage
}) {
  const userWebpack = (0, _shared.getWebpack)(cosmosConfig.rootDir);

  if (!userWebpack) {
    return;
  }

  const webpackConfig = (0, _webpackConfig.getDevWebpackConfig)(cosmosConfig, userWebpack); // Serve static path derived from devServer.contentBase webpack config

  if (cosmosConfig.staticPath === null) {
    const staticPath = getWebpackStaticPath(webpackConfig);

    if (staticPath !== null) {
      (0, _static.serveStaticDir)(expressApp, (0, _config.resolvePath)(cosmosConfig.rootDir, staticPath), cosmosConfig.publicUrl);
    }
  }

  function sendBuildMessage(msg) {
    sendMessage(msg);
  }

  const webpackCompiler = userWebpack(webpackConfig);
  webpackCompiler.hooks.invalid.tap('Cosmos', filePath => {
    const relFilePath = _path.default.relative(process.cwd(), filePath);

    console.log('[Cosmos] webpack build invalidated by', relFilePath);
    sendBuildMessage({
      type: 'buildStart'
    });
  });
  webpackCompiler.hooks.failed.tap('Cosmos', () => {
    sendBuildMessage({
      type: 'buildError'
    });
  });
  const onCompilationDone = new Promise(resolve => {
    webpackCompiler.hooks.done.tap('Cosmos', stats => {
      resolve();

      if (stats.hasErrors()) {
        sendBuildMessage({
          type: 'buildError'
        });
      } else {
        sendBuildMessage({
          type: 'buildDone'
        });
      }
    });
  });
  console.log('[Cosmos] Building webpack...'); // Why import WDM here instead of at module level? Because it imports webpack,
  // which might not be installed in the user's codebase. If this were to happen
  // the Cosmos server would crash with a cryptic import error. See import here:
  // https://github.com/webpack/webpack-dev-middleware/blob/eb2e32bab57df11bdfbbac19474eb16817d504fe/lib/fs.js#L8
  // Instead, prior to importing WDM we check if webpack is installed and fail
  // gracefully if not.

  const wdm = require('webpack-dev-middleware');

  const wdmInst = wdm(webpackCompiler, {
    // publicPath is the base path for the webpack assets and has to match
    // webpack.output.path
    publicPath: (0, _static.getRootUrl)(cosmosConfig.publicUrl),
    logLevel: 'warn'
  });
  expressApp.use(wdmInst);
  const {
    hotReload
  } = (0, _webpack.createWebpackCosmosConfig)(cosmosConfig);

  if (hotReload) {
    expressApp.use((0, _webpackHotMiddleware.default)(webpackCompiler));
  }

  await onCompilationDone;
  return async () => {
    await new Promise(res => wdmInst.close(res));
  };
}

function getWebpackStaticPath({
  devServer
}) {
  return devServer && typeof devServer.contentBase === 'string' ? devServer.contentBase : null;
}