"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.webpackExport = webpackExport;

var _shared = require("./shared");

var _webpackConfig = require("./webpackConfig");

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

async function webpackExport({
  cosmosConfig
}) {
  const userWebpack = (0, _shared.getWebpack)(cosmosConfig.rootDir);

  if (!userWebpack) {
    return;
  }

  const webpackConfig = (0, _webpackConfig.getExportWebpackConfig)(cosmosConfig, userWebpack);

  try {
    await runWebpackCompiler(userWebpack, webpackConfig);
  } catch (err) {
    const webpackError = err;

    if (webpackError.webpackErrors) {
      webpackError.webpackErrors.forEach(error => {
        console.error(`${error}\n`);
      });
    }

    throw webpackError;
  }
}

function runWebpackCompiler(userWebpack, webpackConfig) {
  return new Promise((resolve, reject) => {
    const compiler = userWebpack(webpackConfig);
    compiler.run((err, stats) => {
      if (err) {
        reject(err);
      } else if (stats.hasErrors()) {
        const error = new WebpackCompilationError();
        error.webpackErrors = stats.toJson().errors;
        reject(error);
      } else {
        resolve(stats);
      }
    });
  });
}

class WebpackCompilationError extends Error {
  constructor() {
    super('Webpack errors occurred');

    _defineProperty(this, "webpackErrors", void 0);
  }

}