"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getDefaultWebpackConfig = getDefaultWebpackConfig;

var _resolveFrom = _interopRequireDefault(require("resolve-from"));

var _playgroundHtml = require("../../../shared/playgroundHtml");

var _shared = require("./shared");

var _htmlPlugin = require("./htmlPlugin");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

// This config doesn't have entry and output set up because it's not meant to
// work standalone. An entry & output will be added to this base config.
function getDefaultWebpackConfig(userWebpack, rootDir) {
  // react-cosmos doesn't directly depend on any webpack loader.
  // Instead, it includes the ones already installed by the user.
  const tsLoaderPath = _resolveFrom.default.silent(rootDir, 'ts-loader');

  const babelLoaderPath = _resolveFrom.default.silent(rootDir, 'babel-loader');

  const styleLoaderPath = _resolveFrom.default.silent(rootDir, 'style-loader');

  const cssLoaderPath = _resolveFrom.default.silent(rootDir, 'css-loader'); // Note: Since webpack >= v2.0.0, importing of JSON files will work by default


  const jsonLoaderPath = _resolveFrom.default.silent(rootDir, 'json-loader');

  const rules = [];
  const plugins = [];

  if (tsLoaderPath) {
    rules.push({
      test: /\.tsx?$/,
      loader: tsLoaderPath
    });
  } else if (babelLoaderPath) {
    rules.push({
      test: /\.(js|ts)x?$/,
      exclude: /node_modules/,
      use: {
        loader: babelLoaderPath,
        options: {
          root: rootDir
        }
      }
    });
  }

  if (styleLoaderPath && cssLoaderPath) {
    rules.push({
      test: /\.css$/,
      loader: cssLoaderPath ? `${styleLoaderPath}!${cssLoaderPath}` : styleLoaderPath,
      exclude: /node_modules/
    }); // Preprocess 3rd party .css files located in node_modules

    rules.push({
      test: /\.css$/,
      loader: cssLoaderPath ? `${styleLoaderPath}!${cssLoaderPath}` : styleLoaderPath,
      include: /node_modules/
    });
  }

  if (jsonLoaderPath) {
    rules.push({
      test: /\.json$/,
      loader: jsonLoaderPath,
      exclude: /node_modules/
    });
  }

  const htmlWebpackPlugin = (0, _htmlPlugin.getHtmlWebpackPlugin)(rootDir);

  if (htmlWebpackPlugin) {
    plugins.push(new htmlWebpackPlugin({
      title: 'React Cosmos',
      filename: _playgroundHtml.RENDERER_FILENAME
    }));
  }

  const config = {
    // Besides other advantages, cheap-module-source-map is compatible with
    // React.componentDidCatch https://github.com/facebook/react/issues/10441
    devtool: 'cheap-module-source-map',
    resolve: {
      // Warning: webpack 1.x expects ['', '.js', '.jsx']
      extensions: ['.js', '.jsx', '.ts', '.tsx']
    },
    module: {
      // Note: `module.rules` only works with webpack >=2.x. For 1.x
      // compatibility a custom webpack config (with module.loaders) is required
      rules
    },
    plugins
  };
  const webpack4 = userWebpack.version && parseInt(userWebpack.version, 10) >= 4;

  if (!webpack4) {
    return config;
  }

  return _objectSpread({}, config, {
    mode: (0, _shared.getNodeEnv)(),
    optimization: {
      // Cosmos reads component names at run-time, so it is crucial to not
      // minify even when building with production env (ie. when exporting)
      // https://github.com/react-cosmos/react-cosmos/issues/701
      minimize: false
    }
  });
}