"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getExportWebpackConfig = getExportWebpackConfig;

var _path = _interopRequireDefault(require("path"));

var _shared = require("./shared");

var _htmlPlugin = require("./htmlPlugin");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function getExportWebpackConfig(cosmosConfig, userWebpack) {
  const baseWebpackConfig = (0, _shared.getUserWebpackConfig)(cosmosConfig, userWebpack);
  return _objectSpread({}, baseWebpackConfig, {
    entry: getEntry(),
    output: getOutput(cosmosConfig),
    module: _objectSpread({}, baseWebpackConfig.module, {
      rules: getRules(baseWebpackConfig)
    }),
    plugins: getPlugins(cosmosConfig, baseWebpackConfig, userWebpack)
  });
}

function getEntry() {
  // The React devtools hook needs to be imported before any other module that
  // might import React
  const devtoolsHook = (0, _shared.resolveDomRendererPath)('reactDevtoolsHook');
  const clientIndex = (0, _shared.resolveClientPath)('index');
  return [devtoolsHook, clientIndex];
}

function getOutput({
  exportPath,
  publicUrl
}) {
  const filename = '[name].js';
  return {
    // Most paths are created using forward slashes regardless of the OS for
    // consistency, but this one needs to have backslashes on Windows!
    path: _path.default.join(exportPath, publicUrl),
    filename,
    publicPath: publicUrl
  };
}

function getRules(baseWebpackConfig) {
  const existingRules = baseWebpackConfig.module && baseWebpackConfig.module.rules || [];
  return [...existingRules, (0, _shared.getUserDepsLoaderRule)()];
}

function getPlugins(cosmosConfig, baseWebpackConfig, userWebpack) {
  const existingPlugins = baseWebpackConfig.plugins || [];
  const globalsPlugin = (0, _shared.getGlobalsPlugin)(cosmosConfig, userWebpack, false);
  const noEmitErrorsPlugin = new userWebpack.NoEmitOnErrorsPlugin();
  return (0, _htmlPlugin.ensureHtmlWebackPlugin)(cosmosConfig, [...existingPlugins, globalsPlugin, noEmitErrorsPlugin]);
}