"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getUserWebpackConfig = getUserWebpackConfig;
exports.getBaseWebpackConfig = getBaseWebpackConfig;
exports.resolveDomRendererPath = resolveDomRendererPath;
exports.resolveClientPath = resolveClientPath;
exports.getUserDepsLoaderRule = getUserDepsLoaderRule;
exports.getGlobalsPlugin = getGlobalsPlugin;
exports.hasPlugin = hasPlugin;
exports.isInstanceOfPlugin = isInstanceOfPlugin;
exports.getNodeEnv = getNodeEnv;

var _path = _interopRequireDefault(require("path"));

var _yargs = require("yargs");

var _fs = require("../../../shared/fs");

var _webpack = require("../cosmosConfig/webpack");

var _default = require("./default");

var _module = require("./module");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function getUserWebpackConfig(cosmosConfig, userWebpack) {
  const baseWebpackConfig = getBaseWebpackConfig(cosmosConfig, userWebpack);
  const {
    overridePath
  } = (0, _webpack.createWebpackCosmosConfig)(cosmosConfig);

  if (!overridePath || !(0, _fs.moduleExists)(overridePath)) {
    return baseWebpackConfig;
  }

  const relPath = _path.default.relative(process.cwd(), overridePath);

  console.log(`[Cosmos] Overriding webpack config at ${relPath}`);
  const webpackOverride = (0, _module.getDefaultExport)((0, _fs.requireModule)(overridePath));
  return webpackOverride(baseWebpackConfig, getNodeEnv());
}

function getBaseWebpackConfig(cosmosConfig, userWebpack) {
  const {
    rootDir
  } = cosmosConfig;
  const {
    configPath
  } = (0, _webpack.createWebpackCosmosConfig)(cosmosConfig);

  if (!configPath || !(0, _fs.moduleExists)(configPath)) {
    console.log('[Cosmos] Using default webpack config');
    return (0, _default.getDefaultWebpackConfig)(userWebpack, rootDir);
  }

  const relPath = _path.default.relative(process.cwd(), configPath);

  console.log(`[Cosmos] Using webpack config found at ${relPath}`);
  const userConfigExport = (0, _module.getDefaultExport)((0, _fs.requireModule)(configPath));
  return typeof userConfigExport === 'function' ? userConfigExport(_yargs.argv.env || getNodeEnv(), _yargs.argv) : userConfigExport;
}

function resolveDomRendererPath(relPath) {
  return require.resolve(`../../../domRenderer/${relPath}`);
}

function resolveClientPath(relPath) {
  return require.resolve(`../client/${relPath}`);
}

function getUserDepsLoaderRule() {
  return {
    loader: require.resolve('./userDepsLoader'),
    include: resolveClientPath('userDeps')
  };
}

function getGlobalsPlugin({
  publicUrl
}, userWebpack, devServerOn) {
  const cleanPublicUrl = removeTrailingSlash(publicUrl);
  return new userWebpack.DefinePlugin({
    // "if (__DEV__)" blocks get stripped when compiling a static export build
    __DEV__: JSON.stringify(devServerOn),
    'process.env': {
      NODE_ENV: JSON.stringify(getNodeEnv()),
      PUBLIC_URL: JSON.stringify(cleanPublicUrl)
    }
  });
}

function hasPlugin(plugins, pluginName) {
  return plugins && plugins.filter(p => isInstanceOfPlugin(p, pluginName)).length > 0;
}

function isInstanceOfPlugin(plugin, constructorName) {
  return plugin.constructor && plugin.constructor.name === constructorName;
}

function removeTrailingSlash(url) {
  return url.replace(/\/$/, '');
}

function getNodeEnv() {
  // Disallow non dev/prod environments, like "test" inside Jest, because
  // they are not supported by webpack
  return process.env.NODE_ENV === 'production' ? 'production' : 'development';
}