"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.startDevServer = startDevServer;

var _config = require("../../config");

var _static = require("../static");

var _httpServer = require("./httpServer");

var _app = require("./app");

var _messageHandler = require("./messageHandler");

async function startDevServer(platformType, plugins = []) {
  const cosmosConfig = (0, _config.getCosmosConfig)();
  const app = (0, _app.createApp)(platformType, cosmosConfig);

  if (cosmosConfig.staticPath) {
    (0, _static.serveStaticDir)(app, cosmosConfig.staticPath, cosmosConfig.publicUrl);
  }

  const pluginCleanupCallbacks = [];
  const httpServer = (0, _httpServer.createHttpServer)(cosmosConfig, app);
  await httpServer.start();
  const msgHandler = (0, _messageHandler.createMessageHandler)(httpServer.server);

  async function cleanUp() {
    await pluginCleanupCallbacks.map(cleanup => cleanup());
    await httpServer.stop();
    msgHandler.cleanUp();
  }

  try {
    for (const plugin of plugins) {
      const pluginReturn = await plugin({
        cosmosConfig,
        httpServer: httpServer.server,
        expressApp: app,
        sendMessage: msgHandler.sendMessage
      });

      if (typeof pluginReturn === 'function') {
        pluginCleanupCallbacks.push(pluginReturn);
      }
    }
  } catch (err) {
    cleanUp();
    throw err;
  }

  return cleanUp;
}