"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createMessageHandler = createMessageHandler;

var _debug = _interopRequireDefault(require("debug"));

var _socket = _interopRequireDefault(require("socket.io"));

var _build = require("react-cosmos-shared2/build");

var _renderer = require("react-cosmos-shared2/renderer");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const d = (0, _debug.default)('cosmos:message');

function createMessageHandler(httpServer) {
  d('init');
  const io = (0, _socket.default)(httpServer);
  io.on('connection', socket => {
    d('connection'); // Forward commands between connected clients. Parties involved can be the
    // - The Cosmos UI, which acts as a remote control
    // - The web iframe or the React Native component renderers

    socket.on(_renderer.RENDERER_MESSAGE_EVENT_NAME, msg => {
      d('on renderer message %o', msg);
      socket.broadcast.emit(_renderer.RENDERER_MESSAGE_EVENT_NAME, msg);
    });
  });

  function sendMessage(msg) {
    d('send server message %o', msg);
    io.emit(_build.SERVER_MESSAGE_EVENT_NAME, msg);
  }

  function cleanUp() {
    const {
      sockets
    } = io.sockets;
    Object.keys(sockets).forEach(id => {
      sockets[id].disconnect(true);
    });
  }

  return {
    sendMessage,
    cleanUp
  };
}