"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.generateExport = generateExport;

var _path = _interopRequireDefault(require("path"));

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _config = require("../config");

var _static = require("./static");

var _playgroundHtml = require("./playgroundHtml");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

async function generateExport(plugins = []) {
  const cosmosConfig = (0, _config.getCosmosConfig)(); // Copy static assets first, so that the built index.html overrides the its
  // template file (in case the static assets are served from the root path)

  copyStaticAssets(cosmosConfig);
  await Promise.all(plugins.map(plugin => plugin({
    cosmosConfig
  })));
  exportPlaygroundFiles(cosmosConfig);
  console.log('[Cosmos] Export complete!');
  console.log(`Export path: ${cosmosConfig.exportPath}`);
}

function copyStaticAssets(cosmosConfig) {
  const {
    staticPath
  } = cosmosConfig;

  if (!staticPath) {
    return;
  }

  const {
    exportPath
  } = cosmosConfig;

  if (exportPath.indexOf(staticPath) !== -1) {
    console.warn(`[Cosmos] Warning: Can't export static path because it contains the export path! (avoiding infinite loop)`);
    console.warn('Public path:', staticPath);
    console.warn('Export path:', exportPath);
    return;
  }

  if (!_fsExtra.default.existsSync(staticPath)) {
    console.log('[Cosmos] Warning: config.staticPath points to missing dir', staticPath);
    return;
  }

  const {
    publicUrl
  } = cosmosConfig;

  const exportStaticPath = _path.default.join(exportPath, publicUrl);

  _fsExtra.default.copySync(staticPath, exportStaticPath);
}

function exportPlaygroundFiles(cosmosConfig) {
  const {
    exportPath
  } = cosmosConfig;

  _fsExtra.default.copySync(require.resolve('react-cosmos-playground2/dist'), `${exportPath}/_playground.js`);

  _fsExtra.default.copySync((0, _static.getStaticPath)('favicon.ico'), `${exportPath}/_cosmos.ico`);

  const playgroundHtml = (0, _playgroundHtml.getExportPlaygroundHtml)(cosmosConfig);

  _fsExtra.default.writeFileSync(`${exportPath}/index.html`, playgroundHtml);
}