"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getDevPlaygroundHtml = getDevPlaygroundHtml;
exports.getExportPlaygroundHtml = getExportPlaygroundHtml;
exports.RENDERER_FILENAME = void 0;

var _fs = _interopRequireDefault(require("fs"));

var _shared = require("./shared");

var _slash = require("./slash");

var _static = require("./static");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const RENDERER_FILENAME = '_renderer.html';
exports.RENDERER_FILENAME = RENDERER_FILENAME;

function getDevPlaygroundHtml(platformType, cosmosConfig) {
  const {
    ui
  } = cosmosConfig;
  return getPlaygroundHtml(_objectSpread({}, ui, {
    core: getDevCoreConfig(platformType, cosmosConfig)
  }));
}

function getExportPlaygroundHtml(cosmosConfig) {
  const {
    ui
  } = cosmosConfig;
  return getPlaygroundHtml(_objectSpread({}, ui, {
    core: getExportCoreConfig(cosmosConfig)
  }));
}

function getDevCoreConfig(platformType, cosmosConfig) {
  switch (platformType) {
    case 'native':
      return _objectSpread({}, getSharedCoreConfig(cosmosConfig), {
        devServerOn: true,
        webRendererUrl: null
      });

    case 'web':
      return _objectSpread({}, getSharedCoreConfig(cosmosConfig), {
        devServerOn: true,
        webRendererUrl: getWebRendererUrl(cosmosConfig)
      });

    default:
      throw new Error(`Invalid platform type: ${platformType}`);
  }
}

function getExportCoreConfig(cosmosConfig) {
  return _objectSpread({}, getSharedCoreConfig(cosmosConfig), {
    devServerOn: false,
    webRendererUrl: getWebRendererUrl(cosmosConfig)
  });
}

function getSharedCoreConfig(cosmosConfig) {
  const {
    rootDir,
    fixturesDir,
    fixtureFileSuffix
  } = cosmosConfig;
  return {
    projectId: rootDir,
    fixturesDir,
    fixtureFileSuffix
  };
}

function getWebRendererUrl({
  publicUrl
}) {
  return (0, _slash.slash)(publicUrl, RENDERER_FILENAME);
}

function getPlaygroundHtml(playgroundConfig) {
  return (0, _shared.replaceKeys)(getPlaygroundHtmlTemplate(), {
    __PLAYGROUND_CONFIG: JSON.stringify(playgroundConfig)
  });
}

function getPlaygroundHtmlTemplate() {
  return _fs.default.readFileSync((0, _static.getStaticPath)('index.html'), 'utf8');
}