"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.slash = slash;

var _path = _interopRequireDefault(require("path"));

var _slash2 = _interopRequireDefault(require("slash"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Convert Windows backslash paths to slash paths.
// Context: Node uses appropriate path separators based on the platform it runs
// on. Forward slash on Unix and backward slash on Windows.
// So why normalize slashes if Node takes care of this abstraction?
// Because we use globs often. And some implementations only work with forward
// slashes: https://github.com/isaacs/node-glob#windows
// Initial encounter: https://github.com/react-cosmos/react-cosmos/issues/288
// For further study: https://github.com/micromatch/micromatch#backslashes
// Node supports either on Windows, anyway.
// https://nodejs.org/api/path.html#path_path_win32
function slash(...paths) {
  return paths.length > 1 ? (0, _slash2.default)(_path.default.join(...paths)) : (0, _slash2.default)(paths[0]);
}