"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getStaticPath = getStaticPath;
exports.getRootUrl = getRootUrl;
exports.serveStaticDir = serveStaticDir;

var _express = _interopRequireDefault(require("express"));

var _path = _interopRequireDefault(require("path"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function getStaticPath(relPath) {
  return _path.default.join(__dirname, 'static', relPath);
}

function getRootUrl(publicUrl) {
  // To enable deploying static exports running from inside a nested path,
  // publicUrl can be set to `./`.
  // (See https://github.com/react-cosmos/react-cosmos/issues/777)
  // But publicUrl is used in for some paths which must begin with `/`:
  // - As publicPath in webpack-dev-middleware
  // - As the Express path for serving static assets
  // These are server-side modules (running in dev server mode) that only
  // respond to incoming paths which begin with the root URL we specify.
  return publicUrl === './' ? '/' : publicUrl;
}

function serveStaticDir(app, staticPath, publicUrl) {
  const relStaticPath = _path.default.relative(process.cwd(), staticPath);

  console.log(`[Cosmos] Serving static files from ${relStaticPath}`);
  app.use(getRootUrl(publicUrl), _express.default.static(staticPath, {
    // Ensure loader index (generated by html-webpack-plugin) loads instead
    // of the index.html from staticPath
    index: false
  }));
}