"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.findUserModulePaths = findUserModulePaths;

var _glob = _interopRequireDefault(require("glob"));

var _micromatch = _interopRequireDefault(require("micromatch"));

var _util = _interopRequireDefault(require("util.promisify"));

var _shared = require("./shared");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const globAsync = (0, _util.default)(_glob.default);

async function findUserModulePaths({
  rootDir,
  fixturesDir,
  fixtureFileSuffix
}) {
  const paths = await globAsync('**/*', {
    cwd: rootDir,
    absolute: true,
    ignore: (0, _shared.getIgnorePatterns)()
  });
  const fixturePatterns = (0, _shared.getFixturePatterns)(fixturesDir, fixtureFileSuffix);
  const fixturePaths = getMatchingPaths(paths, fixturePatterns);
  const decoratorPaths = getMatchingPaths(paths, (0, _shared.getDecoratorPatterns)()); // IDEA: Omit fixture paths that are also decorator paths. Relevant only if
  // it becomes useful to put decorator files inside fixture dirs.

  return {
    fixturePaths,
    decoratorPaths
  };
}

function getMatchingPaths(paths, patterns) {
  return (0, _micromatch.default)(paths, patterns, {
    dot: true
  });
}