"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.generateUserDepsModule = generateUserDepsModule;

var _path = _interopRequireDefault(require("path"));

var _slash = require("../slash");

var _findUserModulePaths = require("./findUserModulePaths");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Warning: Renderer config must be serializable!
async function generateUserDepsModule(cosmosConfig, rendererConfig) {
  const {
    rootDir,
    fixturesDir,
    fixtureFileSuffix,
    globalImports
  } = cosmosConfig;
  const {
    fixturePaths,
    decoratorPaths
  } = await (0, _findUserModulePaths.findUserModulePaths)({
    rootDir,
    fixturesDir,
    fixtureFileSuffix
  });
  return getCompiledTemplate({
    globalImports: genGlobalRequires(globalImports),
    rendererConfig: stringifyRendererConfig(rendererConfig),
    fixtures: genRequireMap(fixturePaths, rootDir),
    decorators: genRequireMap(decoratorPaths, rootDir)
  });
}

function genGlobalRequires(paths) {
  if (paths.length === 0) {
    return '';
  }

  return ['', '// Keeping global imports here is superior to making them bundle entry points', '// because this way they become hot-reloadable', ...paths.map(importPath => `import '${importPath}';`), ''].join(`\n`);
}

function genRequireMap(paths, rootDir) {
  if (paths.length === 0) {
    return '{}';
  }

  const requireRows = paths.map(p => {
    const relPath = (0, _slash.slash)(_path.default.relative(rootDir, p));
    return `
  '${relPath}': require('${p}').default`;
  });
  return `{${requireRows.join(', ')}\n}`;
}

function stringifyRendererConfig(rendererConfig) {
  return JSON.stringify(rendererConfig, null, 2);
}

function getCompiledTemplate({
  globalImports,
  rendererConfig,
  fixtures,
  decorators
}) {
  return `// This file is automatically generated by Cosmos
${globalImports}
export const rendererConfig = ${rendererConfig};
export const fixtures = ${fixtures};
export const decorators = ${decorators};
`;
}